#[native]Expand description
Generates the extern "C" wrapper that reads the AMX argument table, parses
it into the Rust types declared in the signature and invokes the marked method.
#[native]Generates the extern "C" wrapper that reads the AMX argument table, parses
it into the Rust types declared in the signature and invokes the marked method.