initialize_plugin!() { /* proc-macro */ }Expand description
Generates the entry points required by the server (SA-MP + Open Multiplayer), the Rust
IComponent vtable and the registration of the plugin’s native list.
initialize_plugin!() { /* proc-macro */ }Generates the entry points required by the server (SA-MP + Open Multiplayer), the Rust
IComponent vtable and the registration of the plugin’s native list.